check_conflicting_calibrations checks if calibrations are younger or older
relative to descendants and ancestors, respectively.
check_conflicting_calibrations(phy, calibration_distribution)A phylo object.
A list of node age distributions, named with phy's node numbers.
It removes conflicting calibrations if needed, but BLADJ works as long as it has an age for the root.