Cluster a patristic matrix into a tree with various methods.
cluster_patristicmatrix(patristic_matrix, variance_matrix = NULL)A list of trees obtained with clustering methods detailed in patristic_matrix_to_phylo().
A patristic matrix
A variance matrix from a datelifeResult object,
usually an output from datelife_result_variance_matrix().
Only used if clustering_method = "mvr".
If clustering method fails, NA is returned.