congruify_and_mrca congruifies a target tree against a single
source chronogram, and gets nodes of target tree that correspond to the most
recent common ancestor (mrca) of taxon pairs from the congruified calibrations.
It uses phytools::findMRCA() to get mrca nodes.
congruify_and_mrca_phylo(phy, source_chronogram, reference)a data.frame of node ages from source_chronograms and corresponding
mrca nodes in target tree phy.
A phylo object.
A phylo object, output of datelife_search().
A character string indicating the study reference that the source_chronogram comes from.