datelifeResult object using the Super Distance Matrix (SDM) method.Reconstruct a supertree from a datelifeResult object using the Super Distance Matrix (SDM) method.
datelife_result_sdm_phylo(datelife_result, weighting = "flat", ...)A supertree with branch lengths proportional to time, obtained by
summarizing individual chronograms given as input in datelife_result.
It is returned as an object of class datelifeSDM, which is a phylo object
with an additional $data element storing the input chronograms as a
datelifeResult object, and a $citation element containing
citations of studies from input chronograms.
A datelifeResult object, usually an output of get_datelife_result().
A character vector indicating how much weight to give to each
tree in input during the SDM analysis. Options are:
All trees have equal weighting.
Weight is proportional to number of taxa.
Weight is proportional to 1 / number of taxa.
Defaults to weighting = "flat".
Arguments passed on to summary_matrix_to_phylo
summ_matrixAny summary patristic distance matrix, such as the ones obtained with datelife_result_sdm_matrix() or datelife_result_median_matrix().
total_distanceWhether the input summ_matrix stores total age distance
(from tip to tip) or distance from node to tip. Default to TRUE,
divides the matrix in half, if FALSE it will take it as is.
useA character vector indicating what type of age to use for summary tree. One of the following:
It will use the mean() of the node ages in summ_matrix.
It uses the stats::median() age of node ages in summ_matrix.
It will use the min() age from node ages in summ_matrix.
Choose this if you wanna be conservative; it will use the max()
age from node ages in summ_matrix.
It will use the mean of minimum age and maximum age.
target_treeA phylo object. Use this in case you want a specific
backbone for the output tree.
datelife_queryA datelifeQuery object, usually an output of make_datelife_query().
Chronograms given as input in datelife_result are summarized with the Super Distance
Matrix (SDM) method described in Criscuolo et al. (2006) tools:::Rd_expr_doi("10.1080/10635150600969872"),
implemented with the function ape::SDM(). The resulting summary SDM is
clustered with summary_matrix_to_phylo().
Criscuolo A, Berry V, Douzery EJ, Gascuel O. (2006) "SDM: a fast distance-based approach for (super) tree building in phylogenomics" tools:::Rd_expr_doi("10.1080/10635150600969872").