get_biggest_multiphylo: Get the tree with the most tips from a multiPhylo object: the biggest tree.
Description
Get the tree with the most tips from a multiPhylo object: the biggest tree.
Usage
get_biggest_multiphylo(trees)
Value
The largest tree from those given in trees, as a phylo object with an additional $citation element containing the reference of the original publication.
Arguments
- trees
A list of trees as multiPhylo or as a generic list object.