get_datelife_result takes as input a vector of taxon names, a newick string,
a phylo object, or adatelifeQuery object. It searches the chronogram
database specified in cache for chronograms matching two or more given
taxon names. For each matching chronogram, it extracts time of lineage
divergence data and stores it as a patristic matrix. It then lists all
resulting patristic matrices. Each list element is named with the study
citation of the source chronogram.
get_datelife_result(
input = NULL,
partial = TRUE,
cache = "opentree_chronograms",
update_opentree_chronograms = FALSE,
...
)A datelifeResult object -- a named list of patristic matrices.
One of the following:
With taxon names as a single comma separated
starting or concatenated with c().
As a phylo or
multiPhylo object, OR as a newick character string.
datelifeQuery objectAn output from make_datelife_query().
Whether to return or exclude partially matching source chronograms,
i.e, those that match some and not all of taxa given in datelife_query.
Options are TRUE or FALSE. Defaults to TRUE: return all matching source
chronograms.
A character vector of length one, with the name of the data object
to cache. Default to "opentree_chronograms", a data object storing Open Tree of
Life's database chronograms and other associated information.
Whether to update the chronogram database or not.
Defaults to FALSE.
Arguments passed on to make_datelife_query
use_tnrsWhether to use Open Tree of Life's Taxonomic Name Resolution Service (TNRS)
to process input taxon names. Default to TRUE, it corrects misspellings and
taxonomic name variations with tnrs_match(), a wrapper of rotl::tnrs_match_names().
get_spp_from_taxonWhether to search ages for all species belonging to a
given taxon or not. Default to FALSE. If TRUE, it must have same length as input.
If input is a newick string with some clades it will be converted to a phylo
object, and the order of get_spp_from_taxon will match phy$tip.label.
reference_taxonomyA character vector specifying the reference taxonomy to use for TNRS. Options are "ott", "ncbi", "gbif" or "irmng". The function defaults to "ott".