Get an Open Tree of Life synthetic subtree of a set of given taxon names.
get_otol_synthetic_tree(
input = NULL,
ott_ids = NULL,
otol_version = "v3",
resolve = FALSE,
...
)A phylo object
Optional. A character vector of names or a datelifeQuery object.
If not NULL, it takes this argument and ignores input. A
numeric vector of ott ids obtained with rotl::taxonomy_taxon_info() or
rotl::tnrs_match_names() or tnrs_match().
Version of Open Tree of Life to use
Defaults to TRUE. Whether to resolve the tree at random or not.
Arguments passed on to check_ott_input