datelifeQuery objectis_datelife_query checks for two things to be TRUE or FALSE.
First, that input is of class datelifeQuery.
Second, that input is a list that contains at least two elements of a datelifeQuery object:
A character vector of taxon names.
Either NA or a phylo object.
is_datelife_query(input)Is determined by the second condition.
An object to be checked as an object with essential properties of a 'datelifeQuery' object.
If the object has the correct format but it has a class different than
datelifeQuery, the class is not modified.