Check if we obtained an empty search with the given taxon name(s).
is_datelife_result_empty(datelife_result, use_tnrs = FALSE)Boolean. If TRUE, no chronograms were found for the given taxon name(s).
If FALSE, the chronogram search was successful.
A datelifeResult object, usually an output of get_datelife_result().
Whether to use Open Tree of Life's Taxonomic Name Resolution Service (TNRS)
to process input taxon names. Default to TRUE, it corrects misspellings and
taxonomic name variations with tnrs_match(), a wrapper of rotl::tnrs_match_names().