phylo object.Congruify a patristic matrix array from a given phylo object.
patristic_matrix_array_phylo_congruify(
patristic_matrix,
target_tree,
dating_method = "PATHd8",
attempt_fix = TRUE
)A matrix.
A patristic matrix, rownames and colnames must be taxa.
A phylo object. Use this in case you want a specific
backbone for the output tree.
The method used for tree dating.
Default to TRUE. If congruification results in NA branch
lengths, it will attempt to fix them.