patristic_matrix_name_reorder: Reorder a matrix so that row and column labels are in alphabetical order.
Description
patristic_matrix_name_reorder is only used in: patristic_matrix_pad().
Usage
patristic_matrix_name_reorder(patristic_matrix)
Value
A patristic matrix with row and column names for taxa in alphabetical order.
Arguments
- patristic_matrix
A patristic matrix, rownames and colnames must be taxa.