Used in: patristic_matrix_list_to_array().
patristic_matrix_pad(patristic_matrix, all_taxa)A patristic matrix, with NA for entries between taxa
where at least one was not in the original patristic matrix.
A patristic matrix, rownames and colnames must be taxa.
A vector of names of all taxa you want, including ones not in the patristic matrix.