phylo objects.Subset a reference and a target tree given as phylo objects.
phylo_subset_both(
reference_tree,
taxa,
phy = NULL,
phy4 = NULL,
dating_method = "PATHd8"
)A list with a patristic matrix array and a $problem if any.
A phylo object.
Vector of taxon names to get a subset for.
A user tree to congruify as phylo object (ape).
A user tree to congruify in phylo4 format (phylobase).
The method used for tree dating.