phylo object.Get a patristic matrix from a phylo object.
phylo_to_patristic_matrix(phy, test = TRUE, tol = 0.01, option = 2)A patristic matrix.
A phylo object.
Default to TRUE. Whether to test if phy has branch lengths and is ultrametric or not.
branching time in reference above which secondary constraints will be applied to target
an integer (1 or 2; see details).