use_all_calibrations generates one or multiple chronograms
(i.e., phylogenetic trees with branch lengths proportional to time) by dating
a tree topology given in phy, and secondary calibrations given in
calibrations, using the algorithm specified in the argument dating_method.
use_all_calibrations(
phy = NULL,
calibrations = NULL,
each = FALSE,
dating_method = "bladj",
...
)A phylo or multiPhylo object with branch lengths proportional to time.
A phylo object to use as tree topology.
A calibrations object, an output of get_all_calibrations().
Boolean, default to FALSE: all calibrations are returned in
the same data.frame. If TRUE, calibrations from each chronogram are returned
in separate data frames.
Tree dating algorithm to use. Options are "bladj" or "pathd8" (Webb et al., 2008, tools:::Rd_expr_doi("10.1093/bioinformatics/btn358"); Britton et al., 2007, tools:::Rd_expr_doi("10.1080/10635150701613783")).
Arguments passed on to use_calibrations
typeThe type of age to use as calibration. Options are "median", "mean", "min", or "max".
The output object stores the used calibrations and dating_method as
attributes(output)$datelife_calibrations and attributes(output)$dating_method.
If phy has no branch lengths, dating_method is ignores, and the function applies secondary
calibrations to date the tree with the BLADJ algorithm. See make_bladj_tree() and use_calibrations_bladj().
If phy has branch lengths, the function can use the PATHd8 algorithm. See use_calibrations_pathd8().
Webb, C. O., Ackerly, D. D., & Kembel, S. W. (2008). "Phylocom: software for the analysis of phylogenetic community structure and trait evolution". Bioinformatics, 24(18), tools:::Rd_expr_doi("10.1093/bioinformatics/btn358").
Britton, T., Anderson, C. L., Jacquet, D., Lundqvist, S., & Bremer, K. (2007). "Estimating divergence times in large phylogenetic trees". Systematic biology, 56(5), 741-752. tools:::Rd_expr_doi("10.1080/10635150701613783").