cluster_patristicmatrix() obtained
with a particular clustering method, or the next best tree.
If there are no ultrametric trees, it does not force them to be ultrametric.Choose an ultrametric phylo object from cluster_patristicmatrix() obtained
with a particular clustering method, or the next best tree.
If there are no ultrametric trees, it does not force them to be ultrametric.
choose_cluster(phycluster, clustering_method = "nj")A phylo object or NA.
An output from cluster_patristicmatrix()
A character vector indicating the method to construct the tree. Options are:
Neighbor-Joining method applied with ape::nj().
Unweighted Pair Group Method with Arithmetic Mean method applied
with phangorn::upgma().
An improved version of the Neighbor-Joining method applied with
ape::bionj().
Triangles method applied with ape::triangMtd()
Minimum Variance Reduction method applied with ape::mvr().