phylo object.Go from a summary matrix to an ultrametric phylo object.
summary_matrix_to_phylo(
summ_matrix,
datelife_query = NULL,
target_tree = NULL,
total_distance = TRUE,
use = "mean",
...
)An ultrametric phylo object.
Any summary patristic distance matrix, such as the ones obtained with datelife_result_sdm_matrix() or datelife_result_median_matrix().
A datelifeQuery object, usually an output of make_datelife_query().
A phylo object. Use this in case you want a specific
backbone for the output tree.
Whether the input summ_matrix stores total age distance
(from tip to tip) or distance from node to tip. Default to TRUE,
divides the matrix in half, if FALSE it will take it as is.
A character vector indicating what type of age to use for summary tree. One of the following:
It will use the mean() of the node ages in summ_matrix.
It uses the stats::median() age of node ages in summ_matrix.
It will use the min() age from node ages in summ_matrix.
Choose this if you wanna be conservative; it will use the max()
age from node ages in summ_matrix.
It will use the mean of minimum age and maximum age.
Arguments passed on to summary_matrix_to_phylo_all
It can take a regular patristic distance matrix, but there are simpler
methods for that implemented in patristic_matrix_to_phylo().