datelifeResult object.Get minimum, median, mean, midpoint, and maximum summary chronograms from a
summary matrix of a datelifeResult object.
summary_matrix_to_phylo_all(
summ_matrix,
datelife_query = NULL,
target_tree = NULL,
total_distance = TRUE,
...
)A multiPhylo object of length 5. It contains min, mean, median, midpoint, and max summary chronograms.
Any summary patristic distance matrix, such as the ones obtained with datelife_result_sdm_matrix() or datelife_result_median_matrix().
A datelifeQuery object, usually an output of make_datelife_query().
A phylo object. Use this in case you want a specific
backbone for the output tree.
Whether the input summ_matrix stores total age distance
(from tip to tip) or distance from node to tip. Default to TRUE,
divides the matrix in half, if FALSE it will take it as is.
Arguments passed on to get_otol_synthetic_tree
otol_versionVersion of Open Tree of Life to use
resolveDefaults to TRUE. Whether to resolve the tree at random or not.
inputOptional. A character vector of names or a datelifeQuery object.
ott_idsIf not NULL, it takes this argument and ignores input. A
numeric vector of ott ids obtained with rotl::taxonomy_taxon_info() or
rotl::tnrs_match_names() or tnrs_match().
With this function users can choose the minimum, mean or maximum ages from
the summary matrix as calibration points to get a single summary chronogram.
Users get all three summary chronograms in a multiPhylo object.