use_calibrations combines all given calibrations and uses them as
constraints to perform a dating analysis on a given tree topology, using BLADJ
if it has no branch lengths, or PATHd8 if the given tree topology has initial
branch lengths.
use_calibrations(
phy = NULL,
calibrations = NULL,
dating_method = "bladj",
type = "median",
...
)A phylo object with branch lengths proportional to time.
A phylo object to use as tree topology.
A calibrations object, an output of get_all_calibrations().
Tree dating algorithm to use. Options are "bladj" or "pathd8" (Webb et al., 2008, tools:::Rd_expr_doi("10.1093/bioinformatics/btn358"); Britton et al., 2007, tools:::Rd_expr_doi("10.1080/10635150701613783")).
The type of age to use as calibration. Options are "median", "mean", "min", or "max".
Arguments passed on to use_calibrations_pathd8
expandHow much to expand by each step to get consistent calibrations. Should be between 0 and 1.
giveupHow many expansions to try before giving up
The output object stores the used calibrations and dating_method as
attributes(output)$datelife_calibrations and attributes(output)$dating_method.
If phy has no branch lengths, dating_method is ignores, and the function applies secondary
calibrations to date the tree with the BLADJ algorithm. See make_bladj_tree() and use_calibrations_bladj().
If phy has branch lengths, the function can use the PATHd8 algorithm. See use_calibrations_pathd8().