use_calibrations_each wraps use_calibrations to take each set of
given calibrations and use it independently as constraints for BLADJ or PATHd8
to date a given tree topology.
use_calibrations_each(phy = NULL, calibrations = NULL, ...)A multiPhylo object of trees with branch lengths proportional to time.
A phylo object to use as tree topology.
A calibrations object, an output of get_all_calibrations().
Arguments passed on to use_calibrations
dating_methodTree dating algorithm to use. Options are "bladj" or "pathd8" (Webb et al., 2008, tools:::Rd_expr_doi("10.1093/bioinformatics/btn358"); Britton et al., 2007, tools:::Rd_expr_doi("10.1080/10635150701613783")).
typeThe type of age to use as calibration. Options are "median", "mean", "min", or "max".
The output object stores the used calibrations and dating_method as
attributes(output)$datelife_calibrations and attributes(output)$dating_method.
If phy has no branch lengths, dating_method is ignores, and the function applies secondary
calibrations to date the tree with the BLADJ algorithm. See make_bladj_tree() and use_calibrations_bladj().
If phy has branch lengths, the function can use the PATHd8 algorithm. See use_calibrations_pathd8().